@@ -8,7 +8,7 @@ Locale::CLDR - A Module to create locale objects with localisation data from the
 
 =head1 VERSION
 
-Version 0.25.5
+Version 0.26.2
 
 =head1 SYNOPSIS
 
@@ -39,7 +39,7 @@ or
 
 use v5.10;
 use version;
-our $VERSION = version->declare('v0.25.5');
+our $VERSION = version->declare('v0.26.2');
 
 use open ':encoding(utf8)';
 use utf8;
@@ -58,6 +58,8 @@ use List::Util qw(first);
 use Class::MOP;
 use DateTime::Locale;
 use Unicode::Normalize();
+#use Locale::CLDR::Collator();
+use File::Spec();
 
 # Backwards compatibility
 BEGIN {
@@ -65,26 +67,8 @@ BEGIN {
 		*fc = \&CORE::fc;
 	}
 	else {
-		# This code taken from Unicode::CaseFold by Andrew Rodland
-		require Unicode::UCD;
-		*fc = sub {
-			my ($string) = @_;
-			
-			my $out = "";
-
-			for my $codepoint (unpack "U*", $string) {
-				my $mapping = Unicode::UCD::casefold($codepoint);
-				my @cp;
-				if (!defined $mapping) {
-					@cp = ($codepoint);
-				} else {
-					@cp = map hex, split / /, $mapping->{'full'};
-				}
-				$out .= pack "U*", @cp;
-			}
-
-			return $out;
-		};
+		# We only use fc() with code that expects Perl v5.18 or above
+		*fc = sub {};
 	}
 }
 
@@ -431,11 +415,6 @@ Vai Digits
 
 =back
 
-Note that the code currently only handles digits ie locales with 
-characters corresponding to 0 - 9, if you use a numerical number
-type it will fall back to C<latn>. Later versions are planned to 
-handle numerals correctly.
-
 =item ca
 
 =item calendar
@@ -546,7 +525,7 @@ stringify a locale object.
 
 Given a locale with no language passed in or with the explicit language
 code of C<und>, this method attempts to use the script and territory
-data to guess the locales language.
+data to guess the locale's language.
 
 =cut
 
@@ -571,7 +550,7 @@ sub _build_likely_language {
 =item likely_script()
 
 Given a locale with no script passed in this method attempts to use the
-language and territory data to guess the locales script.
+language and territory data to guess the locale's script.
 
 =cut
 
@@ -596,7 +575,7 @@ sub _build_likely_script {
 =item likely_territory()
 
 Given a locale with no territory passed in this method attempts to use the
-language and script data to guess the locales territory.
+language and script data to guess the locale's territory.
 
 =back
 
@@ -653,14 +632,14 @@ sub _build_module {
 	# Note the order we push these onto the stack is important
 	@path = join '::', @likely_path;
 	push @path, join '::', $likely_path[0], 'Any', $likely_path[2];
-	push @path, join '::', @likely_path[0 .. 1], 'Any';
-	push @path, join '::', $likely_path[0], 'Any', 'Any';
+	push @path, join '::', @likely_path[0 .. 1];
+	push @path, join '::', $likely_path[0];
 	
 	# Now we go through the path loading each module
 	# And calling new on it. 
 	my $module;
 	foreach my $module_name (@path) {
-		$module_name = "Locale::CLDR::$module_name";
+		$module_name = "Locale::CLDR::Locales::$module_name";
 		eval { Class::Load::load_class($module_name); };
 		next if $@;
 		$module = $module_name->new;
@@ -670,9 +649,10 @@ sub _build_module {
 	# If we only have the root module then we have a problem as
 	# none of the language specific data is in the root. So we
 	# fall back to the en module
-	if (! $module || ref $module eq 'Locale::CLDR::Root') {
-		Class::Load::load_class('Locale::CLDR::En');
-		$module = Locale::CLDR::En->new
+
+	if ( ref $module eq 'Locale::CLDR::Locales::Root') {
+		Class::Load::load_class('Locale::CLDR::Locales::En');
+		$module = Locale::CLDR::Locales::En->new
 	}
 
 	return $module;
@@ -728,31 +708,31 @@ for the language.
 
 =item name
 
-The locales name. This is usually built up out of the language, 
+The locale's name. This is usually built up out of the language, 
 script, territory and variant of the locale
 
 =item language
 
-The name of the locales language
+The name of the locale's language
 
 =item script
 
-The name of the locales script
+The name of the locale's script
 
 =item territory
 
-The name of the locales territory
+The name of the locale's territory
 
 =item variant
 
-The name of the locales variant
+The name of the locale's variant
 
 =back
 
 =head2 Native Meta Data
 
 Like Meta Data above this provides the names of the various id's 
-passed into the locales constructor. However in this case the
+passed into the locale's constructor. However in this case the
 names are formatted to match the locale. I.e. if you passed 
 C<language =E<gt> 'fr'> to the constructor you would get back 
 C<français> for the language.
@@ -761,25 +741,25 @@ C<français> for the language.
 
 =item native_name
 
-The locales name. This is usually built up out of the language, 
-script, territory and variant of the locale. Returned in the locales
+The locale's name. This is usually built up out of the language, 
+script, territory and variant of the locale. Returned in the locale's
 language and script
 
 =item native_language
 
-The name of the locales language in the locales language and script.
+The name of the locale's language in the locale's language and script.
 
 =item native_script
 
-The name of the locales script in the locales language and script.
+The name of the locale's script in the locale's language and script.
 
 =item native_territory
 
-The name of the locales territory in the locales language and script.
+The name of the locale's territory in the locale's language and script.
 
 =item native_variant
 
-The name of the locales variant in the locales language and script.
+The name of the locale's variant in the locale's language and script.
 
 =back
 
@@ -963,7 +943,7 @@ foreach my $property (qw(
 =item date_format_medium 
 
 =item date_format_short
-	
+
 =item time_format_full
 
 =item time_format_long
@@ -971,11 +951,11 @@ foreach my $property (qw(
 =item time_format_medium
 
 =item time_format_short
-	
+
 =item datetime_format_full
 
 =item datetime_format_long
-	
+
 =item datetime_format_medium
 
 =item datetime_format_short
@@ -1060,6 +1040,17 @@ has 'prefers_24_hour_time' => (
 Returns the numeric representation of the first day of the week
 With 0 = Saturday
 
+=item get_day_period($time)
+
+This method will calculate the correct
+period for a given time and return the period name in
+the locale's language and script
+
+=item format_for($date_time_format)
+
+This method takes a CLDR date time format and returns
+the localised version of the format.
+
 =cut
 
 has 'first_day_of_week' => (
@@ -1171,13 +1162,13 @@ sub BUILDARGS {
 		foreach ($language, $script, $territory, $variant) {
 			$_ = '' unless defined $_;
 		}
-			
+
 		%args = (
-			language_id	=> $language,
+			language_id		=> $language,
 			script_id		=> $script,
 			territory_id	=> $territory,
 			variant_id		=> $variant,
-			extensions	=> $extensions,
+			extensions		=> $extensions,
 		);
 	}
 
@@ -1459,7 +1450,7 @@ If you don't pass in a locale then it will use $self.
 
 =item locale_name($name)
 
-Returns the given locale name in the current locales format. The name can be
+Returns the given locale name in the current locale's format. The name can be
 a locale id or a locale object or non existent. If a name is not passed in
 then the name of the current locale is returned.
 
@@ -1480,7 +1471,7 @@ sub locale_name {
 		return $display_name if defined $display_name;
 	}
 
-	# $name can be a string or a Locale::CLDR::*
+	# $name can be a string or a Locale::CLDR::Locales::*
 	if (! ref $name) {
 		$name = Locale::CLDR->new($name);
 	}
@@ -1499,7 +1490,7 @@ sub locale_name {
 
 =item language_name($language)
 
-Returns the language name in the current locales format. The name can be
+Returns the language name in the current locale's format. The name can be
 a locale language id or a locale object or non existent. If a name is not
 passed in then the language name of the current locale is returned.
 
@@ -1565,7 +1556,7 @@ sub all_languages {
 
 =item script_name($script)
 
-Returns the script name in the current locales format. The script can be
+Returns the script name in the current locale's format. The script can be
 a locale script id or a locale object or non existent. If a script is not
 passed in then the script name of the current locale is returned.
 
@@ -1633,7 +1624,7 @@ sub all_scripts {
 
 =item territory_name($territory)
 
-Returns the territory name in the current locales format. The territory can be
+Returns the territory name in the current locale's format. The territory can be
 a locale territory id or a locale object or non existent. If a territory is not
 passed in then the territory name of the current locale is returned.
 
@@ -1677,7 +1668,7 @@ sub territory_name {
 =item all_territories
 
 Returns a hash ref keyed on territory id of all the territory the system 
-knows about. The values are the territory names for the corresponding id's 
+knows about. The values are the territory names for the corresponding ids 
 
 =cut
 
@@ -1701,7 +1692,7 @@ sub all_territories {
 
 =item variant_name($variant)
 
-Returns the variant name in the current locales format. The variant can be
+Returns the variant name in the current locale's format. The variant can be
 a locale variant id or a locale object or non existent. If a variant is not
 passed in then the variant name of the current locale is returned.
 
@@ -1732,7 +1723,7 @@ sub variant_name {
 
 =item key_name($key)
 
-Returns the key name in the current locales format. The key must be
+Returns the key name in the current locale's format. The key must be
 a locale key id as a string
 
 =cut
@@ -1764,7 +1755,7 @@ sub key_name {
 
 =item type_name($key, $type)
 
-Returns the type name in the current locales format. The key and type must be
+Returns the type name in the current locale's format. The key and type must be
 a locale key id and type id as a string
 
 =cut
@@ -1797,7 +1788,7 @@ sub type_name {
 	
 =item measurement_system_name($measurement_system)
 
-Returns the measurement system name in the current locales format. The measurement system must be
+Returns the measurement system name in the current locale's format. The measurement system must be
 a measurement system id as a string
 
 =cut
@@ -1820,7 +1811,7 @@ sub measurement_system_name {
 
 =item transform_name($name)
 
-Returns the transform (transliteration) name in the current locales format. The transform must be
+Returns the transform (transliteration) name in the current locale's format. The transform must be
 a transform id as a string
 
 =cut
@@ -1841,8 +1832,8 @@ sub transform_name {
 
 =item code_pattern($type, $locale)
 
-This method formats a language, script or territory name, given as $type
-from $locale in a way expected by the current locale. If $locale is
+This method formats a language, script or territory name, given as C<$type>
+from C<$locale> in a way expected by the current locale. If $locale is
 not passed in or is undef() the method uses the current locale.
 
 =cut
@@ -1930,7 +1921,7 @@ Note you need Perl 5.18 or above for this
 
 =item split_grapheme_clusters($string)
 
-Splits a string on grapheme clusters using the locals segmentation rules.
+Splits a string on grapheme clusters using the locale's segmentation rules.
 Returns a list of grapheme clusters.
 
 =cut
@@ -1953,7 +1944,7 @@ sub split_grapheme_clusters {
 
 =item split_words($string)
 
-Splits a string on word boundaries using the locals segmentation rules.
+Splits a string on word boundaries using the locale's segmentation rules.
 Returns a list of words.
 
 =cut
@@ -1972,7 +1963,7 @@ sub split_words {
 =item split_sentences($string)
 
 Splits a string on on all points where a sentence could
-end using the locals segmentation rules. Returns a list
+end using the locale's segmentation rules. Returns a list
 the end of each list element is the point where a sentence
 could end.
 
@@ -1992,7 +1983,7 @@ sub split_sentences {
 =item split_lines($string)
 
 Splits a string on on all points where a line could
-end using the locals segmentation rules. Returns a list
+end using the locale's segmentation rules. Returns a list
 the end of each list element is the point where a line
 could end.
 
@@ -2070,7 +2061,7 @@ sub _split {
 =item is_exemplar_character($character)
 
 Tests if the given character is used in the locale. There are 
-three possible types; c<main>, C<auxiliary> and c<punctuation>.
+three possible types; C<main>, C<auxiliary> and C<punctuation>.
 If no type is given C<main> is assumed. Unless the C<index> type
 is given you will have to have a Perl version of 5.18 or above
 to use this method
@@ -2096,7 +2087,7 @@ sub is_exemplar_character {
 =item index_characters()
 
 Returns an array ref of characters normally used when creating 
-an index.
+an index and ordered appropriately.
 
 =cut
 
@@ -2217,7 +2208,7 @@ sub truncated_word_end {
 
 =item quote($string)
 
-Adds the locales primary quotation marks to the ends of the string.
+Adds the locale's primary quotation marks to the ends of the string.
 Also scans the string for paired primary and auxiliary quotation
 marks and flips them.
 
@@ -2381,7 +2372,7 @@ sub all_units {
 
 Returns the localised string for the given number and unit formatted for the 
 required width. The number must not be the localized version of the number.
-The returned string will be in the locales format, including the number.
+The returned string will be in the locale's format, including the number.
 
 =cut
 
@@ -2454,8 +2445,8 @@ sub _unit_compound {
 	my @bundles = $self->_find_bundle('units');
 	my $format;
 	foreach my $bundle (@bundles) {
-		if (exists $bundle->units()->{$type}{per}{''}) {
-			$format = $bundle->units()->{$type}{per}{''};
+		if (exists $bundle->units()->{$type}{per}{1}) {
+			$format = $bundle->units()->{$type}{per}{1};
 			last;
 		}
 	}
@@ -2467,8 +2458,8 @@ sub _unit_compound {
 		foreach my $alias (@aliases) {
 			$type = $alias->unit_alias()->{$original_type};
 			foreach my $bundle (@bundles) {
-				if (exists $bundle->units()->{$type}{per}{''}) {
-					$format = $bundle->units()->{$type}{per}{''};
+				if (exists $bundle->units()->{$type}{per}{1}) {
+					$format = $bundle->units()->{$type}{per}{1};
 					last;
 				}
 			}
@@ -2513,9 +2504,9 @@ sub duration_unit {
 
 =item is_yes($string)
 
-Returns true if the passed in string matches the locales 
+Returns true if the passed in string matches the locale's 
 idea of a string designating yes. Note that under POSIX
-rules unless the locales word for yes starts with C<Y>
+rules unless the locale's word for yes starts with C<Y>
 (U+0079) then a single 'y' will also be accepted as yes.
 The string will be matched case insensitive.
 
@@ -2530,9 +2521,9 @@ sub is_yes {
 
 =item is_no($string)
 
-Returns true if the passed in string matches the locales 
+Returns true if the passed in string matches the locale's 
 idea of a string designating no. Note that under POSIX
-rules unless the locales word for yes starts with C<n>
+rules unless the locale's word for no starts with C<n>
 (U+006E) then a single 'n' will also be accepted as no
 The string will be matched case insensitive.
 
@@ -2549,15 +2540,16 @@ sub is_no {
 
 =head2 Transliteration
 
-This method requires Perl version 5.18 or above to use
+This method requires Perl version 5.18 or above to use and for you to have
+installed the optional C<Bundle::CLDR::Transformations>
 
 =over 4
 
 =item transform(from => $from, to => $to, variant => $variant, text => $text)
 
 This method returns the transliterated string of C<text> from script C<from>
-to script C<to> using variant C<variant>. If c<from> is not given then the 
-current locales script is used. If C<text> is not given then it defaults to an
+to script C<to> using variant C<variant>. If C<from> is not given then the 
+current locale's script is used. If C<text> is not given then it defaults to an
 empty string. The C<variant> is optional.
 
 =cut
@@ -2664,7 +2656,7 @@ sub _transformation_transform {
 		}
 	}
 	return $text;
-}		
+}
 
 sub _transform_convert {
 	my ($self, $text, $rules) = @_;
@@ -2715,7 +2707,8 @@ sub list {
 	
 	my %list_data;
 	foreach my $bundle (reverse @bundles) {
-		%list_data = %{$bundle->listPatterns};
+		my %listPatterns = %{$bundle->listPatterns};
+		@list_data{keys %listPatterns} = values %listPatterns;
 	}
 	
 	if (my $pattern = $list_data{scalar @data}) {
@@ -2747,9 +2740,15 @@ sub list {
 	return $pattern;
 }
 
+=back
+
+=head2 Pluralisation
+
+=over 4
+
 =item plural($number)
 
-This method takes a number and uses the locales pluralisation
+This method takes a number and uses the locale's pluralisation
 rules to calculate the type of pluralisation required for
 units, currencies and other data that changes depending on
 the plural state of the number
@@ -2994,14 +2993,6 @@ sub _build_quarter_stand_alone_narrow {
 	return $self->_build_any_quarter($type, $width);
 }
 
-=item get_day_period($time)
-
-This method will calculate the correct
-period for a given time and return the period name in
-the Locales language and script
-
-=cut
-
 sub get_day_period {
 	# Time in hhmm
 	my ($self, $time) = @_;
@@ -3407,12 +3398,6 @@ sub _build_format_data {
 	return {};
 }
 
-=item format_for
-
-TODO fix this 
-
-=cut
-
 sub format_for {
 	my ($self, $format) = @_;
 
@@ -3650,6 +3635,41 @@ This method returns a hash that maps valid variant codes to their valid aliases
 
 =head2 Information about weeks
 
+There are no standard codes for the days of the weeks so CLDR uses the following
+three letter codes to represent unlocalised days
+
+=over 4
+
+=item sun
+
+Sunday
+
+=item mon
+
+Monday
+
+=item tue
+
+Tuesday
+
+=item wed
+
+Wednesday
+
+=item thu
+
+Thursday
+
+=item fri
+
+Friday
+
+=item sat
+
+Saturday
+
+=back
+
 =cut
 
 sub _week_data {
@@ -3672,7 +3692,7 @@ sub _week_data {
 
 This method takes an optional territory id and returns a the minimum number of days
 a week must have to count as the starting week of the new year. It uses the current
-locales territory if no territory id is passed in.
+locale's territory if no territory id is passed in.
 
 =cut
 
@@ -3687,7 +3707,7 @@ sub week_data_min_days {
 
 This method takes an optional territory id and returns the three letter code of the 
 first day of the week for that territory. If no territory id is passed in then it
-uses the current locales territory.
+uses the current locale's territory.
 
 =cut
 
@@ -3702,7 +3722,7 @@ sub week_data_first_day {
 
 This method takes an optional territory id and returns the three letter code of the 
 first day of the week end for that territory. If no territory id is passed in then it
-uses the current locales territory.
+uses the current locale's territory.
 
 =cut
 
@@ -3717,7 +3737,7 @@ sub week_data_weekend_start {
 
 This method takes an optional territory id and returns the three letter code of the 
 first day of the week end for that territory. If no territory id is passed in then it
-uses the current locales territory.
+uses the current locale's territory.
 
 =cut
 
@@ -3736,7 +3756,7 @@ sub week_data_weekend_end {
 
 =item territory_contains()
 
-This method returns a hash ref keyed on territory id. The value is an array ref
+This method returns a hash ref keyed on territory id. The value is an array ref.
 Each element of the array ref is a territory id of a territory immediately 
 contained in the territory used as the key
 
@@ -3782,6 +3802,10 @@ releases.
 $for_cash is only used during currency formatting. If true then cash rounding
 will be used otherwise financial rounding will be used. 
 
+This function also handles rule based number formatting. If $format is string equivalent
+to one of the current locale's public rule based number formats then $number will be 
+formatted according to that rule. 
+
 =item add_currency_symbol($format, $symbol)
 
 This method returns the format with the currency symbol $symbol correctly inserted
@@ -3789,7 +3813,7 @@ into the format
 
 =item parse_number_format($format, $currency, $currency_data, $for_cash)
 
-This method parses a CLDR format string into a hash ref containing data used to 
+This method parses a CLDR numeric format string into a hash ref containing data used to 
 format a number. If a currency is being formatted then $currency contains the
 currency code, $currency_data is a hashref containing the currency rounding
 information and $for_cash is a flag to signal cash or financial rounding. 
@@ -3888,7 +3912,7 @@ The cash rounding increment, in units of 10^-cashdigits.
 =item default_currency($territory_id)
 
 This method returns the default currency id for the territory id.
-If no territory id is given then the current locales is used
+If no territory id is given then the current locale's is used
 
 =cut
 
@@ -3916,7 +3940,7 @@ sub default_currency {
 =item currency_symbol($currency_id)
 
 This method returns the currency symbol for the given currency id in the current locale.
-If no currency id is given it uses the locales default currency
+If no currency id is given it uses the locale's default currency
 
 =cut
 
@@ -3952,6 +3976,63 @@ used the territory of the current locale.
 
 =back
 
+=begin comment
+
+=head2 Collation
+
+=over 4
+
+=item collation()
+
+This method returns a Locale::CLDR::Collator object. This is still in development. Future releases will
+try and match the API from L<Unicode::Collate> as much as possible and add tailoring for locales.
+
+=back
+
+=end comment
+
+=cut
+
+=begin comment
+
+sub collation {
+	my ($self, %params) = @_;
+	
+	$params{type} //= $self->_default_collation;
+	$params{strength} //= $self->_default_collation_strength;
+	
+	return Locale::CLDR::Collator->new(locale => $self, %params);
+}
+
+sub collation_overrides {
+	my ($self, $type) = @_;
+	
+	my @bundles = reverse $self->_find_bundle('collation');
+	
+	my $override = '';
+	foreach my $bundle (@bundles) {
+		last if $override = $bundle->collation()->{$type};
+	}
+	
+	if ($type ne 'standard' && ! $override) {
+		foreach my $bundle (@bundles) {
+			last if $override = $bundle->collation()->{standard};
+		}
+	}
+	
+	return $override || [];
+}
+	
+sub _default_collation {
+	return 'standard';
+}
+
+sub _default_collation_strength {
+	return 3;
+}
+
+=end comment
+
 =head1 AUTHOR
 
 John Imrie, C<< <john dot imrie1 at gmail dot com> >>
@@ -3998,11 +4079,6 @@ Everyone at the Unicode Consortium for providing the data.
 Karl Williams for his tireless work on Unicode in the Perl 
 regex engine.
 
-Andrew Rodland for his L<Unicode::CaseFold> module that I
-pinched the fc() code from for early versions of Perl that
-don't have this function.
-
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2009-2014 John Imrie.
